
library('depmixS4') #the HMM library we’ll use
library('quantmod') #a great library for technical analysis and working with time series 
EURUSD1d<-read.csv('EURUSD1d.csv')
Date<-as.character(EURUSD1d[,1])
DateTS<- as.POSIXlt(Date, format = "%Y.%m.%d %H:%M:%S") #create date and time objects
TSData<-data.frame(EURUSD1d[,2:5],row.names=DateTS)
TSData<-as.xts(TSData) #build our time series data set

ATRindicator<-ATR(TSData[,2:4],n=14) #calculate the indicator
ATR<-ATRindicator[,2] #grab just the ATR 

LogReturns <- log(EURUSD1d$Close) - log(EURUSD1d$Open) #calculate the logarithmic returns

ModelData<-data.frame(LogReturns,ATR) #create the data frame for our HMM model

ModelData<-ModelData[-c(1:14),] #remove the data where the indicators are being calculated
colnames(ModelData)<-c("LogReturns","ATR") #name our columns 
set.seed(1)
HMM<-depmix(list(LogReturns~1,ATR~1),data=ModelData,nstates=3,family=list(gaussian(),gaussian())) #We’re setting the LogReturns and ATR as our response variables, using the data frame we just built, want to set 3 different regimes, and setting the response distributions to be gaussian. 

HMMfit<-fit(HMM) #fit our model to the data set

HMMpost<-posterior(HMMfit) #find the posterior odds for each state over our data set

plot(ts(HMMpost[,-1], deltat=1/360),ylab='probability')